# Changelog

## [Unreleased]

## [0.1.2] - 2025-04-05

### Added

-   Start of Changelog

[Unreleased]: https://github.com/boukepostma/mondaytoframe/compare/0.1.2...HEAD

[0.1.2]: https://github.com/boukepostma/mondaytoframe/compare/4f0cd06bcd30aa87a6733bc43af41e8597b4aebb...0.1.2
